@@ -36,7 +36,7 @@ void login_start_session(gchar *host, gint port,
 		ggzcore_server_free(server);
 	server = ggzcore_server_new();
 	ggzcore_server_set_hostinfo(server, host, port, FALSE);
-	ggzcore_server_set_logininfo(server, type, username, password);
+	ggzcore_server_set_logininfo(server, type, username, password, NULL);
 
 	/* Setup callbacks on server */
 	ggz_event_init(server);
